@@ -50,10 +50,11 @@ class ContextChainConfig(BaseModel):
     default_prompt_style: str = "analytical"
     vector_config: Optional[VectorStoreConfig] = None
     llm_config: Optional[LLMConfig] = None
-    llm_provider: str = os.getenv("LLM_PROVIDER", "ollama")  # Default to Ollama
-    llm_model: str = os.getenv("LLM_MODEL", "llama3")  # Default to llama3
-    llm_api_key: Optional[str] = os.getenv("LLM_API_KEY")  # Optional API key
+    llm_provider: str = os.getenv("LLM_PROVIDER", "ollama")
+    llm_model: str = os.getenv("LLM_MODEL", "llama3")
+    llm_api_key: Optional[str] = os.getenv("LLM_API_KEY")
     prompt_config: Optional[PromptConstructionConfig] = None
+    prompt_quality_threshold: float = float(os.getenv("PROMPT_QUALITY_THRESHOLD", "0.5"))
     enable_mongo: bool = False
     mongo_uri: str = "mongodb://localhost:27017/contextchain"
     max_parallel_tasks: int = 5
@@ -86,11 +87,11 @@ class StoreDataRequest(BaseModel):
     data_type: str
     data: Any
     metadata: Optional[Dict] = None
-    destination: Optional[str] = None  # "mongodb" or "postgresql"
+    destination: Optional[str] = None
 
 class FeedbackRequest(BaseModel):
     session_id: str
-    rating: int  # 1-5
+    rating: int
     comments: Optional[str] = None
 
 class ContextChain:
@@ -112,7 +113,8 @@ class ContextChain:
             device=config.llm_config.device if config.llm_config else "cpu"
         )
         self.acba = AdaptiveContextBudgetingAlgorithm(max_tokens=config.max_tokens)
-        self.context_engineer = ContextEngineer(config.prompt_config or PromptConstructionConfig())
+        prompt_cfg = config.prompt_config or PromptConstructionConfig(quality_threshold=config.prompt_quality_threshold)
+        self.context_engineer = ContextEngineer(prompt_cfg)
         self.vector_store = HybridVectorStore(config.vector_config or VectorStoreConfig())
         self.dag_engine = DAGEngine(config.max_parallel_tasks)
         self.storage = IntelligentStorage(mongo_uri=config.mongo_uri) if config.enable_mongo else None
@@ -122,7 +124,7 @@ class ContextChain:
             'avg_latency_ms': 0.0,
             'start_time': datetime.utcnow()
         }
-        logger.info(f"ContextChain v2.0 initialized with LLM provider: {config.llm_provider}, model: {config.llm_model}")
+        logger.info(f"ContextChain v2.0 initialized with LLM provider: {config.llm_provider}, model: {config.llm_model}, quality_threshold: {prompt_cfg.quality_threshold}")
 
     async def initialize(self):
         """Initialize components"""
@@ -305,7 +307,7 @@ class ContextChain:
                 tokens_used=llm_response.tokens_used,
                 tokens_saved=tokens_saved,
                 quality_score=quality_score,
-                budget_allocation=budget.__dict__,
+                budget_allocation=vars(budget),
                 data_routing=data_routing,
                 processing_steps=processing_steps,
                 documents_used=len(retrieved_docs),
@@ -375,8 +377,8 @@ class ContextChain:
             await self.storage.log_interaction(
                 session_id=response.session_id,
                 query=query,
-                complexity=complexity.dict(),
-                budget_allocation=budget.dict(),
+                complexity=vars(complexity),
+                budget_allocation=vars(budget),
                 performance_metrics=performance_metrics,
                 success=response.success,
                 error_message=response.error_message
